#!/bin/bash

#Quick check to ensure all the hardware is physically present in this machine.
#Useful if the PCI card has become dislodged!
#Copyright (C) 2013 Richard Neill. This is Free Software, released under the GNU GPL v3+

if [ $# != 0 ]; then
	echo "This checks for the presence of the necessary hardware plugged into this machine."
	echo "It needs: PulseBlaster PCI, NI-4462 PCI, FTDI245 USB."
	echo "If all well, return 0. If missing, show dialog-box and exit 1."
	exit 1
fi

#Each of the xxx_check scripts is itself verbose (on stdout) when there are errors...

err=0

#Check for PulseBlaster card...
if ! pb_check ;then
	zenity --error --title "ERROR: ircam_hw_check" --text="ERROR: PulseBlaster PCI device not present! Turn off, remove lid and wiggle the PCI cards carefully." &
	err=1
fi

#Check for the NI 4462 card
if ! ni4462_check ;then
	zenity --error --title "ERROR: ircam_hw_check" --text="ERROR: NI 4462 PCI device not present! Turn off, remove lid and wiggle the PCI cards carefully." &
	err=1
fi

#Check for the FTDI245 card
if ! ftdi245io_check ;then
	zenity --error  --title "ERROR: ircam_hw_check" --text="ERROR: FTDI245 USB device not present! Check it is plugged in." &
	err=1
fi

#Check for the Arduino delay.
if ! arduino_check ;then
        zenity --error --title "ERROR: ircam_hw_check" --text="ERROR: Arduino (USB) device not present! Check it is plugged in."
        err=1
fi

#Check for Pulseblaster remote trigger (via serial port). Optional hardware; not necessarily required, so just warn to stdout if it's missing.
if ! pb_serial_trigger_check ;then
        #zenity --error --title "ERROR: pb_serial_trigger_check" --text="Warning: PB Serial Remote Trigger device not present! Check it is plugged in."
        #err=1
	true	#can't have empty stanza.
fi

if [ $err == 0 ] ;then
	echo "Everything is present as expected."
	#Do we want a happy message to confirm all is well?
	zenity --info  --title "Success: ircam_hw_check" --text="All 4 devices (PulseBlaster, NI-4462, FTDI245 USB, Arduino) were detected ok." &
elif [ -n "$SSH_CONNECTION" ]; then
	#Connected remotely; give hint about permissions.
	echo "One or more devices is inaccessible."
	echo "Hint: you are connected via SSH. If this is a permissions issue (and you aren't logged in locally),  try 'pam_console_apply'."
fi
exit $err

